@@ -7,15 +7,15 @@ import inspect
 import json
 import logging
 import warnings
-from datetime import datetime
-from pathlib import PurePath
-from typing import Callable, Optional, Union
+from datetime import datetime, timezone
+from typing import Any, Callable, Coroutine, Optional, Union
 
 from jsonschema import ValidationError
-from pythonjsonlogger import jsonlogger  # type:ignore
+from pythonjsonlogger import jsonlogger
 from traitlets import Dict, Instance, Set, default
 from traitlets.config import Config, LoggingConfigurable
 
+from .schema import SchemaType
 from .schema_registry import SchemaRegistry
 from .traits import Handlers
 from .validators import JUPYTER_EVENTS_CORE_VALIDATOR
@@ -63,7 +63,7 @@ class EventLogger(LoggingConfigurable):
     """
 
     handlers = Handlers(
-        default_value=[],
+        default_value=None,
         allow_none=True,
         help="""A list of logging.Handler instances to send events to.
 
@@ -131,7 +131,7 @@ class EventLogger(LoggingConfigurable):
         eventlogger_cfg = Config({"EventLogger": my_cfg})
         super()._load_config(eventlogger_cfg, section_names=None, traits=None)
 
-    def register_event_schema(self, schema: Union[dict, str, PurePath]):
+    def register_event_schema(self, schema: SchemaType) -> None:
         """Register this schema with the schema registry.
 
         Get this registered schema using the EventLogger.schema.get() method.
@@ -143,28 +143,33 @@ class EventLogger(LoggingConfigurable):
         self._modified_listeners[key] = set()
         self._unmodified_listeners[key] = set()
 
-    def register_handler(self, handler: logging.Handler):
+    def register_handler(self, handler: logging.Handler) -> None:
         """Register a new logging handler to the Event Logger.
 
         All outgoing messages will be formatted as a JSON string.
         """
 
-        def _skip_message(record, **kwargs):
+        def _handle_message_field(record, **kwargs):
+            """Python's logger always emits the "message" field with
+            the value as "null" unless it's present in the schema/data.
+            Message happens to be a common field for event logs,
+            so special case it here and only emit it if "message"
+            is found the in the schema's property list.
             """
-            Remove 'message' from log record.
-            It is always emitted with 'null', and we do not want it,
-            since we are always emitting events only
-            """
-            del record["message"]
+            schema = self.schemas.get(record["__schema__"])
+            if "message" not in schema.properties:
+                del record["message"]
             return json.dumps(record, **kwargs)
 
-        formatter = jsonlogger.JsonFormatter(json_serializer=_skip_message)
+        formatter = jsonlogger.JsonFormatter(
+            json_serializer=_handle_message_field,
+        )
         handler.setFormatter(formatter)
         self._logger.addHandler(handler)
         if handler not in self.handlers:
             self.handlers.append(handler)
 
-    def remove_handler(self, handler: logging.Handler):
+    def remove_handler(self, handler: logging.Handler) -> None:
         """Remove a logging handler from the logger and list of handlers."""
         self._logger.removeHandler(handler)
         if handler in self.handlers:
@@ -175,7 +180,7 @@ class EventLogger(LoggingConfigurable):
         *,
         schema_id: Union[str, None] = None,
         modifier: Callable[[str, dict], dict],
-    ):
+    ) -> None:
         """Add a modifier (callable) to a registered event.
 
         Parameters
@@ -208,9 +213,9 @@ class EventLogger(LoggingConfigurable):
             if schema_id:
                 self._modifiers[schema_id].add(modifier)
                 return
-            for id in self._modifiers:
-                if schema_id is None or id == schema_id:
-                    self._modifiers[id].add(modifier)
+            for id_ in self._modifiers:
+                if schema_id is None or id_ == schema_id:
+                    self._modifiers[id_].add(modifier)
         else:
             msg = (
                 "Modifiers are required to follow an exact function/method "
@@ -249,8 +254,8 @@ class EventLogger(LoggingConfigurable):
         *,
         modified: bool = True,
         schema_id: Union[str, None] = None,
-        listener: Callable[["EventLogger", str, dict], None],
-    ):
+        listener: Callable[["EventLogger", str, dict], Coroutine[Any, Any, None]],
+    ) -> None:
         """Add a listener (callable) to a registered event.
 
         Parameters
@@ -283,10 +288,10 @@ class EventLogger(LoggingConfigurable):
                     self._modified_listeners[schema_id].add(listener)
                     return
                 self._unmodified_listeners[schema_id].add(listener)
-            for id in self.schemas.schema_ids:
-                if schema_id is None or id == schema_id:
+            for id_ in self.schemas.schema_ids:
+                if schema_id is None or id_ == schema_id:
                     if modified:
-                        self._modified_listeners[id].add(listener)
+                        self._modified_listeners[id_].add(listener)
                     else:
                         self._unmodified_listeners[schema_id].add(listener)
         else:
@@ -304,7 +309,7 @@ class EventLogger(LoggingConfigurable):
         self,
         *,
         schema_id: Optional[str] = None,
-        listener: Callable[["EventLogger", str, dict], None],
+        listener: Callable[["EventLogger", str, dict], Coroutine[Any, Any, None]],
     ) -> None:
         """Remove a listener from an event or all events.
 
@@ -327,7 +332,9 @@ class EventLogger(LoggingConfigurable):
                 self._modified_listeners[schema_id].discard(listener)
                 self._unmodified_listeners[schema_id].discard(listener)
 
-    def emit(self, *, schema_id: str, data: dict, timestamp_override=None):
+    def emit(
+        self, *, schema_id: str, data: dict, timestamp_override: Optional[datetime] = None
+    ) -> Optional[dict]:
         """
         Record given event with schema has occurred.
 
@@ -351,7 +358,7 @@ class EventLogger(LoggingConfigurable):
             and not self._modified_listeners[schema_id]
             and not self._unmodified_listeners[schema_id]
         ):
-            return
+            return None
 
         # If the schema hasn't been registered, raise a warning to make sure
         # this was intended.
@@ -361,8 +368,9 @@ class EventLogger(LoggingConfigurable):
                 "this was not intentional, please register the schema using the "
                 "`register_event_schema` method.",
                 SchemaNotRegistered,
+                stacklevel=2,
             )
-            return
+            return None
 
         schema = self.schemas.get(schema_id)
 
@@ -379,10 +387,9 @@ class EventLogger(LoggingConfigurable):
         self.schemas.validate_event(schema_id, modified_data)
 
         # Generate the empty event capsule.
-        if timestamp_override is None:
-            timestamp = datetime.utcnow()
-        else:
-            timestamp = timestamp_override
+        timestamp = (
+            datetime.now(tz=timezone.utc) if timestamp_override is None else timestamp_override
+        )
         capsule = {
             "__timestamp__": timestamp.isoformat() + "Z",
             "__schema__": schema_id,
@@ -400,7 +407,7 @@ class EventLogger(LoggingConfigurable):
 
         # callback for removing from finished listeners
         # from active listeners set.
-        def _listener_task_done(task: asyncio.Task):
+        def _listener_task_done(task: asyncio.Task) -> None:
             # If an exception happens, log it to the main
             # applications logger
             err = task.exception()
@@ -429,7 +436,7 @@ class EventLogger(LoggingConfigurable):
             self._active_listeners.add(task)
 
             # Remove task from active listeners once its finished.
-            def _listener_task_done(task: asyncio.Task):
+            def _listener_task_done(task: asyncio.Task) -> None:
                 # If an exception happens, log it to the main
                 # applications logger
                 err = task.exception()
